@@ -1,22 +1,22 @@
 '''Testing clifold python project'''
-# from src.clifold import main
+# from clifold.clifold import main
 import subprocess
 import shutil
 import os
 
 
 python_path = shutil.which('python3')
-# command = [f'{python_path} main.py -g -p -i', f'{python_path} main.py -ng -np -ni',
-#            f'{python_path} main.py -ng -p -i', f'{python_path} main.py -ng -np -i',
-#            f'{python_path} main.py -g -np -ni', f'{python_path} main.py -ng -p -ni',
-#            f'{python_path} main.py -g -np -i', f'{python_path} main.py -g -p -ni'
+# command = [f'{python_path} clifold_main.py -g -p -i', f'{python_path} clifold_main.py -ng -np -ni',
+#            f'{python_path} clifold_main.py -ng -p -i', f'{python_path} clifold_main.py -ng -np -i',
+#            f'{python_path} clifold_main.py -g -np -ni', f'{python_path} clifold_main.py -ng -p -ni',
+#            f'{python_path} clifold_main.py -g -np -i', f'{python_path} clifold_main.py -g -p -ni'
 #            ]
 
 # for i in range(len(command)):
 #     print(f"Testing Test {i}...")
 #     subprocess.run([command[i]], check=True)
 
-subprocess.run([python_path, 'src/main.py', 'testing', '-g', '-np', '-i'], check=True)
+subprocess.run([python_path, 'clifold/clifold_main.py', 'testing', '-g', '-np', '-i'], check=True)
 os.chdir('testing')
 
 
